#
# spec file for package mdbtools
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libmdb    libmdb3
%define libmdbsql libmdbsql3
Name:           mdbtools
Version:        1.0.0
Release:        1.5
Summary:        A Suite of Libraries and Programs to Access Microsoft Access Databases
License:        GPL-2.0-or-later
Group:          Productivity/Databases/Tools
URL:            https://github.com/mdbtools
Source0:        https://github.com/mdbtools/mdbtools/releases/download/v%{version}/mdbtools-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  txt2man
BuildRequires:  unixODBC-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0)

%description
Mdbtools contains:
mdb-dump -- simple hex dump utility for looking at mdb files
mdb-schema -- prints DDL for the specified table
mdb-export -- export table to CSV format
mdb-tables -- a simple dump of table names to be used with shell scripts
mdb-header -- generates a C header to be used in exporting mdb data to a C prog
mdb-parsecvs -- generates a C program given a CSV file made with mdb-export
mdb-sql -- demo SQL engine program
mdb-ver -- print version of database

%package devel
Summary:        All files necessary for development with the MDB Tools libraries
Group:          Development/Libraries/C and C++
Requires:       %{libmdbsql} = %{version}
Requires:       %{libmdb} = %{version}
Requires:       flex
Requires:       glib2-devel
Requires:       unixODBC-devel

%description devel
Mdbtools contains:
mdb-dump -- simple hex dump utility for looking at mdb files
mdb-schema -- prints DDL for the specified table
mdb-export -- export table to CSV format
mdb-tables -- a simple dump of table names to be used with shell scripts
mdb-header -- generates a C header to be used in exporting mdb data to a C prog
mdb-parsecvs -- generates a C program given a CSV file made with mdb-export
mdb-sql -- demo SQL engine program
mdb-ver -- print version of database

%package -n %{libmdb}
Summary:        MDB Tools ODBC driver for unixODBC
Group:          Productivity/Databases/Tools

%description -n %{libmdb}
Contains shared library %{libmdb} from %{name}

%package -n %{libmdbsql}
Summary:        MDB Tools ODBC driver for unixODBC
Group:          Productivity/Databases/Tools

%description -n %{libmdbsql}
Contains shared library %{libmdbsql} from %{name}

%prep
%autosetup

%build
autoreconf -fiv
%configure \
  --disable-static \
  --with-pic \
  --with-unixodbc=%{_prefix} \
  --disable-gmdb2 \
  --disable-gtk-doc \
  %{nil}
%make_build

%check
%make_build check

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libmdb} -p /sbin/ldconfig
%post -n %{libmdbsql} -p /sbin/ldconfig
%postun -n %{libmdb} -p /sbin/ldconfig
%postun -n %{libmdbsql} -p /sbin/ldconfig

%files
%license COPYING
%doc AUTHORS NEWS HACKING
%{_bindir}/mdb-*
%{_mandir}/man1/mdb-*.1%{?ext_man}
%{_datadir}/bash-completion/completions/mdb-*

%files -n %{libmdb}
%{_libdir}/libmdb.so.3*

%files -n %{libmdbsql}
%{_libdir}/libmdbsql.so.3*

%files devel
%{_includedir}/mdb*.h
%{_libdir}/libmdbsql.so
%{_libdir}/libmdb.so
%dir %{_libdir}/odbc
%{_libdir}/odbc/libmdbodbc.so
%{_libdir}/odbc/libmdbodbcW.so
%{_libdir}/pkgconfig/libmdb.pc
%{_libdir}/pkgconfig/libmdbsql.pc

%changelog
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.0:
  * Install `libmdbodbc.so` and `libmdbodbcW.so` into ${libdir}/odbc
  * Do not install `mdb-sql` if SQL support was not built
  * Do not install `libmdbsql.pc` if SQL support was not built
  * Simplify `--cflags` for libmdb
  * Provide correct `--cflags` for libmdbsql
  * Copy date formats when cloning handles
  * Fix incorrect reading of double values
  * Fix accidental reads of non-index data
  * New `mdb_set_repid_fmt()` for setting the format of Rep IDs (UUIDs)
  * New case-insensitive, Unicode-aware `ILIKE` operator
  * New `<>` (not equal) operator
  * Improved support for comparing floating-point values to integers
  * Improved support for floating point literals with no fractional digits (e.g. "3.")
  * Add support for querying Rep IDs
  * Format boolean values correctly as `SQL_C_CHAR`
  * Add support for the `SQL_C_WCHAR` (UTF-16) return type
  * The Unicode driver (`libmdbodbcW.so`) no longer uses iconv
  * Add support for older iODBC installations lacking `odbcinst.h`
  * Convert table names to lower case when exporting to PostgreSQL
  * Use `CREATE IF NOT EXISTS` when exporting to PostgreSQL
  * Fix issue where byte columns with values > 127 were exported as negative numbers
  * Deprecate tool
* Wed May 19 2021 Martin Pluskal <mpluskal@suse.com>
- Switch to new upstream url
- Update to version 0.9.3 - see NEWS for detailed list of changes
* Sat May 19 2018 bjorn.lie@gmail.com
- No longer build gui sub-package:
  + Drop gnome-common, gtk-doc, libglade2-devel, libgnomeui-devel
    and scrollkeeper.
- Following the above drop gmdb2.desktop, and no longer pass
  - -enable-sql and --enable-gtk-doc to configure, nor handle
  desktop_database_post(un) for the now dropped sub-package. and
  drop gnome_prefix and gnome_datadir defines, no longer used.
- Add explicit --disable-gmdb2 --disable-gtk-doc calls.
- Add pkgconfig(glib-2.0) BuildRequires, new dependency previously
  autoamaticly pulled in.
- Run spec-cleaner, modernize spec.
* Wed Aug  5 2015 mpluskal@suse.com
- Enable building of man pages
* Fri Jul 31 2015 mpluskal@suse.com
- Update to 0.7.1
  * no upstream changelog available
- Cleanup spec file with spec-cleaner
- Use macros for desktop files
- Add explicit dependencies on automake/conf and pkg-config
- Stop building man pages as this depends on txt2man which
  is not available in openSUSE
- Build gnome documentation
- Split libraries to separeate packages
* Thu Jan 22 2015 dimstar@opensuse.org
- Disable parallel build: currently broken with bison 3.0.
* Mon Apr 29 2013 mhrusecky@suse.com
- migrated to the new upstream version 0.7
  https://github.com/brianb/mdbtools
- no detailed changelog
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Jun  7 2010 coolo@novell.com
- fix parallel build
* Wed Dec  2 2009 coolo@novell.com
- updated patches, fix build
* Fri Jan  9 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Mon Oct 13 2008 pth@suse.de
- Add provides so that 0.6pre1 is newer than 20070410cvs.
* Thu Sep 25 2008 ro@suse.de
- call autoreconf -f -i for new libtool
* Mon Aug 18 2008 pth@suse.de
- Update to latest cvs version.
- Remove the use of run_ldconfig
- Mark help files as %%doc
- Remove duplicate requires
- Clean up the code.
* Fri Jun 22 2007 pth@suse.de
- Fix dependencies.
* Tue Apr 10 2007 uli@suse.de
- update -> 20071004cvs (can read GameBase databases)
* Fri Mar 30 2007 rguenther@suse.de
- Add bison and flex BuildRequires
* Thu Feb 16 2006 pth@suse.de
- Fix off by one bug (Bugzilla #151484)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Dec  8 2005 pth@suse.de
- Fix type-punning
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Sat Aug 16 2003 adrian@suse.de
- added desktop file
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Fri Jun 27 2003 pthomas@suse.de
- Actually apply the included patches.
- Add directory to file list.
* Wed Jun 25 2003 pthomas@suse.de
- Initial package creation.
